@@ -129,3 +129,15 @@ class EmailITreeAdapter(adapters.ITreeAdapter):
     __select__ = is_instance('Email')
     tree_relation = 'reply_to'
 
+
+class EmailPartIFTIAdapter(adapters.IFTIndexableAdapter):
+    """customize EmailPart IFTI adapter so we don't index pgp signature"""
+    __select__ = adapters.IFTIndexableAdapter.__select__ & is_instance('EmailPart')
+
+    def get_words(self):
+        try:
+            if self.entity.contenttype == 'application/pgp-signature':
+                return []
+        except AttributeError:
+            return super(EmailPartIFTIAdapter, self).get_words()
+
